@@ -1,5 +1,3 @@
-
-#include <libgnome/gnome-init.h>
 #include <bonobo/bonobo-main.h>
 #include <stdlib.h>
 #include <libebook/e-book.h>
@@ -10,8 +8,6 @@ main (int argc, char **argv)
 	EContact *contact;
 	EContactDate date, *dp;
 
-	gnome_program_init("test-string", "0.0", LIBGNOME_MODULE, argc, argv, NULL);
-
 	if (bonobo_init (&argc, argv) == FALSE)
 		g_error ("Could not initialize Bonobo");
 
@@ -33,4 +29,6 @@ main (int argc, char **argv)
 	  printf ("failed\n");
 	else
 	  printf ("passed\n");
+	
+	return 0;
 }
