@@ -5,16 +5,16 @@
  *  Copyright 2002 Ximian, Inc. (www.ximian.com)
  *
  *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
+ *  it under the terms of the GNU Lesser General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
+ *  You should have received a copy of the GNU Lesser General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
@@ -179,7 +179,7 @@ http_connect (CamelHttpStream *http, CamelURL *url)
 
 	d(printf("connecting to http stream @ '%s'\n", url->host));
 
-	if (!strcasecmp (url->protocol, "https")) {
+	if (!g_ascii_strcasecmp (url->protocol, "https")) {
 #ifdef HAVE_SSL
 		stream = camel_tcp_stream_ssl_new (http->session, url->host, SSL_FLAGS);
 #endif
@@ -267,7 +267,7 @@ http_get_statuscode (CamelHttpStream *http)
 	d(printf("HTTP Status: %s\n", buffer));
 
 	/* parse the HTTP status code */
-	if (!strncasecmp (buffer, "HTTP/", 5)) {
+	if (!g_ascii_strncasecmp (buffer, "HTTP/", 5)) {
 		token = http_next_token (buffer);
 		http->statuscode = camel_header_decode_int (&token);
 		return http->statuscode;
